@@ -66,7 +66,7 @@ protected:
   void setLocationParent( ObjectCalcer* o );
   /**
    * objects you pass here, should be newly created property objects,
-   * that have no children..
+   * that have no children.
    */
   void setPropertyObjects( const argvect& props );
   void setFrame( bool f );
@@ -77,7 +77,7 @@ protected:
   void leftReleased( QMouseEvent*, KigWidget*, ObjectTypeCalcer* prevlabel = 0 );
 
 private:
-  // the KigMode interface..
+  // the KigMode interface.
   void leftClicked( QMouseEvent*, KigWidget* ) Q_DECL_OVERRIDE;
   void leftReleased( QMouseEvent*, KigWidget* ) Q_DECL_OVERRIDE;
 
@@ -107,7 +107,7 @@ class TextLabelConstructionMode
   : public TextLabelModeBase
 {
 public:
-  TextLabelConstructionMode( KigPart& d );
+  explicit TextLabelConstructionMode( KigPart& d );
   ~TextLabelConstructionMode();
 
   void finish( const Coordinate& coord, const QString& s,
@@ -135,7 +135,7 @@ class NumericLabelMode
   : public KigMode
 {
 public:
-  NumericLabelMode( KigPart& d );
+  explicit NumericLabelMode( KigPart& d );
   ~NumericLabelMode();
 
   void redrawScreen( KigWidget* w ) Q_DECL_OVERRIDE;
